import java.awt.Graphics;

public abstract class Area implements Cloneable {
   private static final int DIST = 2;
   private static final int DIST2 = 4;
   private static final int SIZE = 5;
   protected boolean _selected = false;
   protected String _link;

   public abstract void resize(int var1, int var2);

   public abstract void translate(int var1, int var2);

   public abstract boolean isGrab(int var1, int var2);

   public abstract boolean isSelect(int var1, int var2);

   public abstract boolean inside(int var1, int var2);

   public abstract boolean isValid();

   public abstract boolean isComplete();

   public abstract void advance();

   public abstract void draw(Graphics var1);

   public abstract String getShape();

   public abstract String getCoords();

   public abstract synchronized Object clone();

   public void setSelected(boolean var1) {
      this._selected = var1;
   }

   public boolean isSelected() {
      return this._selected;
   }

   public void setLink(String var1) {
      this._link = var1;
   }

   public String getLink() {
      return this._link;
   }

   public String toString() {
      return "<AREA" + this.formatShape() + this.formatCoords() + this.formatLink() + ">";
   }

   private String formatShape() {
      return " SHAPE=\"" + this.getShape() + "\"";
   }

   private String formatCoords() {
      return " COORDS=\"" + this.getCoords() + "\"";
   }

   private String formatLink() {
      return this._link != null && this._link.length() > 0 ? " HREF=\"" + this._link + "\"" : " NOHREF";
   }

   protected boolean grabPoint(int var1, int var2, int var3, int var4) {
      return Math.abs(var3 - var1) <= 2 && Math.abs(var4 - var2) <= 2;
   }

   protected boolean grabLine(int var1, int var2, int var3, int var4, int var5, int var6) {
      if ((var1 - 2 <= var5 && var5 <= var3 + 2 || var3 - 2 <= var5 && var5 <= var1 + 2) && (var2 - 2 <= var6 && var6 <= var4 + 2 || var4 - 2 <= var6 && var6 <= var2 + 2)) {
         if (var1 == var3 || var2 == var4) {
            return true;
         }

         double var7 = (double)(var4 - var2) / (double)(var3 - var1);
         double var9 = (double)(var6 - var2) / var7 + (double)var1 - (double)var5;
         double var11 = var7 * (double)(var5 - var1) + (double)var2 - (double)var6;
         if (var9 == (double)0.0F || var11 == (double)0.0F) {
            return true;
         }

         if ((int)Math.abs(var9 * var11 / Math.sqrt(var9 * var9 + var11 * var11)) <= 2) {
            return true;
         }
      }

      return false;
   }

   protected void drawPoint(Graphics var1, int var2, int var3) {
      var1.fillRect(var2 - 2, var3 - 2, 5, 5);
   }

   protected void drawCenter(Graphics var1, int var2, int var3) {
      var1.drawLine(var2 - 2, var3 - 2, var2 + 2, var3 + 2);
      var1.drawLine(var2 - 2, var3 + 2, var2 + 2, var3 - 2);
   }

   protected void drawAnchor(Graphics var1, int var2, int var3) {
      var1.drawLine(var2, var3 - 4, var2, var3 + 4);
      var1.drawLine(var2 - 4, var3, var2 + 4, var3);
   }
}
