import java.awt.BorderLayout;
import java.awt.Button;
import java.awt.Color;
import java.awt.Container;
import java.awt.Event;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.awt.Label;
import java.awt.Menu;
import java.awt.MenuBar;
import java.awt.Panel;
import java.awt.TextField;
import java.awt.Window;
import mug.app.ApplicationFrame;
import mug.app.CloseCommand;
import mug.app.CommandMenu;
import mug.app.CommandMenuItem;
import mug.app.Document;
import mug.app.NewCommand;
import mug.app.OpenCommand;
import mug.app.QuitCommand;
import mug.app.SaveCommand;
import mug.ui.GridBagPanel;

public class MainShell extends ApplicationFrame {
   private MapCanvas _mapCanvas = new MapCanvas(this);
   private TextField _linkTextField;
   private Button _clearButton;
   private Label _statusLabel;

   public static void main(String[] var0) {
      MainShell var1 = new MainShell("Client Side Image Map Editor");
      var1.show();
   }

   public MainShell(String var1) {
      super(var1);
      this._mapCanvas.setBackground(Color.white);
      ((Container)this).setLayout(new BorderLayout(5, 5));
      GridBagPanel var2 = new GridBagPanel();
      GridBagConstraints var3 = new GridBagConstraints();
      var2.constrain(new Label("Link URL"), var3);
      var2.constrain(this._linkTextField = new TextField(50), var3);
      var3.gridwidth = 0;
      var2.constrain(this._clearButton = new Button("Clear"), var3);
      ((Container)this).add("North", var2);
      Panel var4 = new Panel();
      ((Container)var4).add(new Toolbar(this._mapCanvas));
      ((Container)this).add("West", var4);
      ((Container)this).add("Center", this._mapCanvas);
      ((Container)this).add("South", this._statusLabel = new Label());
      ((Window)this).pack();
      ((ApplicationFrame)this).disableMenuItem("File", "Preferences...");
      ((ApplicationFrame)this).disableMenuItem("Edit", "Undo");
      ((ApplicationFrame)this).disableMenuItem("Help", "Help");
      ((ApplicationFrame)this).disableMenuItem("Help", "About");
   }

   public void show() {
      super.show();
      ((CommandMenuItem)((ApplicationFrame)this).getMenuItem("File", "New")).execute();
   }

   public Insets insets() {
      Insets var1 = super.insets();
      return new Insets(var1.top + 5, var1.left + 5, var1.bottom + 5, var1.right + 5);
   }

   protected MenuBar menuBar() {
      MenuBar var1 = new MenuBar();
      CommandMenu var2 = new CommandMenu("File");
      var2.add("New", (new PreSaveCommand(this)).setNext((new CloseCommand(this)).setNext((new NewCommand(this)).setNext((new ChooseImageCommand(this)).setNext(new MapNameCommand(this))))));
      var2.add("Open...", (new PreSaveCommand(this)).setNext((new CloseCommand(this)).setNext(new OpenCommand(this))));
      var2.add("Save", (new PreSaveCommand(this)).setNext(new SaveCommand(this, false)));
      var2.add("Save As...", (new PreSaveCommand(this)).setNext(new SaveCommand(this, true)));
      ((Menu)var2).addSeparator();
      var2.add("Load Image File...", new LoadImageFileCommand(this));
      var2.add("Load Image URL...", new LoadImageURLCommand(this));
      var2.add("Import Image Map File...", (new PreSaveCommand(this)).setNext((new CloseCommand(this)).setNext((new NewCommand(this)).setNext(new ImportImageMapFileCommand(this)))));
      var2.add("Import Image Map URL...", (new PreSaveCommand(this)).setNext((new CloseCommand(this)).setNext((new NewCommand(this)).setNext(new ImportImageMapURLCommand(this)))));
      ((Menu)var2).addSeparator();
      ((Menu)var2).add("Preferences...");
      ((Menu)var2).addSeparator();
      var2.add("Quit", (new PreSaveCommand(this)).setNext((new CloseCommand(this)).setNext(new QuitCommand())));
      var1.add(var2);
      var2 = new CommandMenu("Edit");
      var2.add("Map Name...", new MapNameCommand(this));
      ((Menu)var2).addSeparator();
      var2.add("Duplicate Selected", new MapCanvasCommand(this, 0));
      var2.add("Delete Selected", new MapCanvasCommand(this, 1));
      ((Menu)var2).addSeparator();
      var2.add("Undo", new MapCanvasCommand(this, 2));
      var1.add(var2);
      var2 = new CommandMenu("Image");
      var2.add("Opaque", new TransparentCommand(this, 255));
      var2.add("25% Transparent", new TransparentCommand(this, 192));
      var2.add("50% Transparent", new TransparentCommand(this, 128));
      var2.add("75% Transparent", new TransparentCommand(this, 64));
      var2.add("Invisible", new TransparentCommand(this, 0));
      var1.add(var2);
      var2 = new CommandMenu("Bookmarks");
      var2.add("Browse Bookmarks File...", new BrowseBookmarksFileCommand(this));
      var1.add(var2);
      var2 = new CommandMenu("View");
      var2.add("HTML Source...", (new PreSaveCommand(this)).setNext(new HTMLSourceCommand(this)));
      var1.add(var2);
      var2 = new CommandMenu("Help");
      ((Menu)var2).add("Help");
      ((Menu)var2).addSeparator();
      ((Menu)var2).add("About");
      var1.setHelpMenu(var2);
      return var1;
   }

   public boolean action(Event var1, Object var2) {
      if (var1.target == this._clearButton) {
         this.setLink("");
         return true;
      } else {
         return false;
      }
   }

   public String getLink() {
      return this._linkTextField.getText();
   }

   public void setLink(String var1) {
      this._linkTextField.setText(var1 != null ? var1 : "");
   }

   public void setStatus(String var1) {
      this._statusLabel.setText(var1 != null ? var1 : "");
   }

   public Document emptyDocument() {
      return new ImageMap();
   }

   public Document getDocument() {
      return this._mapCanvas.getImageMap();
   }

   public void setDocument(Document var1) {
      ((ApplicationFrame)this).setBusy(true);
      this._mapCanvas.setImageMap((ImageMap)var1);
      ((ApplicationFrame)this).setBusy(false);
   }

   public MapCanvas getMapCanvas() {
      return this._mapCanvas;
   }

   protected String overwriteMessage() {
      return "Overwrite existing image map file?\n \nBe careful. The editor only saves HTML tags related\nto the image map itself. All other tags are lost.";
   }
}
